@@ -53,6 +53,11 @@
 /* max length window list menu items */
 #define WLIST_MAXLEN 20
 
+/* Search path for menu.xml file */
+#define SEARCHPATH	(SYSCONFDIR G_DIR_SEPARATOR_S "xfce4" G_DIR_SEPARATOR_S "%F.%L:"\
+                         SYSCONFDIR G_DIR_SEPARATOR_S "xfce4" G_DIR_SEPARATOR_S "%F.%l:"\
+                         SYSCONFDIR G_DIR_SEPARATOR_S "xfce4" G_DIR_SEPARATOR_S "%F")
+
 /* a bit hackish, but works well enough */
 static gboolean is_using_system_rc = TRUE;
 
@@ -175,15 +180,17 @@ void do_edit(gpointer callback_data, guint callback_action, GtkWidget * widget)
 static gchar *
 get_menu_file(void)
 {
+    gchar buffer[PATH_MAX + 1];
     char *filename = NULL;
+    char *path = NULL;
     const char *env;
 
     TRACE("dummy");
     env = g_getenv("XFCE_DISABLE_USER_CONFIG");
 
     if(!env || strcmp(env, "0")) {
+    
         filename = xfce_get_userfile("menu.xml", NULL);
-
         if(g_file_test(filename, G_FILE_TEST_EXISTS))
 	{
 	    is_using_system_rc = FALSE;
@@ -197,12 +204,16 @@ get_menu_file(void)
     }
 
     is_using_system_rc = TRUE;
+
+    /* xfce_get_path_localized(buffer, sizeof(buffer), SEARCHPATH,
+       "menu.xml", G_FILE_TEST_IS_REGULAR);*/
     
-    filename = g_build_filename(SYSCONFDIR, "xfce4", "menu.xml", NULL);
-    if(g_file_test(filename, G_FILE_TEST_EXISTS))
-        return filename;
-    else
-        g_free(filename);
+    path = g_build_filename (SYSCONFDIR, "xfce4", "menu.xml", NULL);
+    filename = xfce_get_file_localized(path);
+    g_free(path);
+
+    if (filename)
+	return filename;
 
     g_warning("%s: Could not locate a menu definition file", PACKAGE);
 
@@ -459,7 +470,7 @@ static GtkWidget *create_desktop_menu(void)
 {
     struct stat st;
     static char *filename = NULL;
-    static time_t ctime = 0;
+    static time_t mtime = 0;
 
     TRACE("dummy");
     if (!filename || is_using_system_rc)
@@ -471,13 +482,27 @@ static GtkWidget *create_desktop_menu(void)
     }
     
     /* may have been removed */
-    if (stat(filename, &st) < 0) {
-        g_free(filename);
+    if (stat(filename, &st) < 0) 
+    {
+        if (filename)
+        {
+            g_free(filename);
+        }
         filename = get_menu_file();
-        ctime = 0;
+        mtime = 0;
     }
 
-    if (!ifactory || !MainMenuData || ctime < st.st_ctime)
+    /* Still no luck? Something got broken! */
+    if (stat(filename, &st) < 0) 
+    {
+        if (filename)
+        {
+            g_free(filename);
+        }
+        return NULL;
+    }
+    
+    if (!ifactory || !MainMenuData || mtime < st.st_mtime)
     {
         GtkItemFactoryEntry entry;
         MenuItem *item = NULL;
@@ -527,7 +552,7 @@ static GtkWidget *create_desktop_menu(void)
         /* Hmmm ... if you do this the menus don't work */
         /* Lets save it in a global var and worry about it later */
         MainMenuData = menu_data;
-        ctime = st.st_ctime;
+        mtime = st.st_mtime;
     }
 
     return gtk_item_factory_get_widget(ifactory, "<popup>");
@@ -778,7 +803,7 @@ static gboolean button_press_event(GtkWidget * win, GdkEventButton * ev,
     static GtkWidget *menu3 = NULL;
 
     TRACE("dummy");
-    if(ev->button == 3 || (ev->button == 1 && ev->state & GDK_SHIFT_MASK))
+    if(ev->button == 2 || (ev->button == 1 && ev->state & GDK_SHIFT_MASK))
     {
         if(menu3)
         {
@@ -787,17 +812,19 @@ static gboolean button_press_event(GtkWidget * win, GdkEventButton * ev,
 
         menu3 = create_windowlist_menu();
 
-        gtk_menu_popup(GTK_MENU(menu3), NULL, NULL, NULL, NULL, 1, ev->time);
+        gtk_menu_popup(GTK_MENU(menu3), NULL, NULL, NULL, NULL, 0, ev->time);
 
         return TRUE;
     }
-    else if(ev->button == 1)
+    else if(ev->button == 3)
     {
         menu1 = create_desktop_menu();
 
-        gtk_menu_popup(GTK_MENU(menu1), NULL, NULL, NULL, NULL, 1, ev->time);
-
-        return TRUE;
+        if (menu1)
+        {
+            gtk_menu_popup(GTK_MENU(menu1), NULL, NULL, NULL, NULL, 0, ev->time);
+            return TRUE;
+        }
     }
 
     return FALSE;
